+++
title = "Michael Dawson's Tri-Level Hypothesis and Cognitive Science"
description = "Paper on Michael Dawson's Tri-Level Hypothesis, and it's place in Cognitive Science."
draft = false
comments = true
date = "2003-11-30T02:01:00-06:00"
slug = "Michael-Dawsons-Tri-Level-Hypothesis-and-Cognitive-Science"
blogengine = "a23befbc-124d-4ca1-bdab-97aca921b2ff"
categories = ["article", "philosophy"]
tags = []
+++

<p>
Michael Dawson, in his book <em>Understanding Cognitive Science</em> attempts to provide a basic understanding of cognitive science, specifically by dealing with and using the &quot;tri-level&quot; hypothesis. For this paper, I will be discussing the tri-level hypothesis and what it tells us about cognitive science.
</p>
<p>
One of the major problems in any science is the problem of discussing the findings within a set field with people outside of the field. Because of this problem, time is instead spent on some lesser subjects, such as sports and the weather. According to Dawson, cognitive science doesn&#39;t have to deal with this problem as much as some other fields in science do. Cognitive science brings various fields/disciplines together into one, overbearing, field, dealing with something along the lines of &quot;&#39;representation of knowledge, language understanding, image understanding, question answering, inference, learning, problem solving, and planning.&#39;&quot; [1: 3] Three fields or disciplines that Dawson speaks of when he talks about the foundations of cognitive science are the fields of psychology, philosophy, and computer science. We will see shortly that these three fields each have some specific part in the tri-level hypothesis.
</p>
<p>
The fundamental assumption of the cognitive science field is that &quot;&#39;the human mind is a complex system that receives, stores, retrieves, transforms, and transmits information&#39; ... in short, the mind is assumed to be an information processor.&quot; [1: 5] From this assumption, which may or may not be true, Dawson, and other cognitive scientists, move towards something resembling the tri-level hypothesis. This hypothesis holds that there are three levels of analysis when we discuss information processing. The first level is the computational level, the second the algorithmic level, and the third is the implementational level. Of course, the ordering of the levels is based solely on what we would like to focus on in our studies. For the rest of this paper, I&#39;ll attempt to stay away from ordering the levels, and instead just call them what Dawson calls them.
</p>
<p>
As I mentioned before, each of the three fields Dawson speaks of in this introduction can be shown to mirror a particular level. The implementational level is where cognitive scientists ask, &quot;What physical properties are used to implement the (functional) method that the system uses to solve this information-processing problem?&quot; [1: 288] The field of psychology asks these kinds of questions, and people of this field are therefore best prepared for examining this particular area.
</p>
<p>
The algorithmic level is where cognitive scientists ask, &quot;What method is the system using to solve this information-processing problem?&quot; [1: 288] The field of computer science, specifically those in the field of programming, asks these kinds of questions, and people of this field are therefore best prepared for examining this particular area. When we examine the steps that an information processor uses to come upon a solution we are looking at this level in the tri-level hypothesis.
</p>
<p>
The computational level is where cognitive scientists ask, &quot;What information-processing problem is the system solving?&quot; [1: 288] The field of philosophy asks these kinds of questions, and people of this field are therefore best situated for examining this particular area. When we examine the problem that the information processor is using certain steps to solve, we are looking at this level in the tri-level hypothesis.
</p>
<p>
It&#39;s important to note that Dawson presents a tri-level hypothesis, so, because of this, no single level tells the whole story of what cognition, or information processing, is. It is only by an examination of each particular question, along with an analysis of how each question relates to, and helps answer, each other question, that one can truly understand cognition.
</p>
<p>
On the surface, this hypothesis appears to be fairly valid. However, without looking at an example of an information-processor, we can&#39;t really make a solid judgment about the safety of Dawson&#39;s hypothesis. One concrete example in the cognitive science literature is the case of a thermostat. For the most part, the average man on the street believes that a thermostat is an information processor since it takes information from the environment and processes it in such a way that we can understand the environment. Of course, it should be noted that the average man on the street is not a cognitive scientist, so this may not be true. If we look at a thermostat in light of the tri-level hypothesis, we may be able to break it up into something such as the following.
</p>
<p>
A thermostat, as stated above, attempts to tell us what the temperature is of the environment that the thermostat lies in. This then would be the information-processing problem that the system is solving (what is the temperature of the environment) and would therefore lie in the computational level. The algorithmic level would be the particular program that the thermostat uses to take the information that it receives and process it so that an observer can see the temperature (perhaps by looking at a digital readout). The implementational level would be the actual physical makeup of the thermostat, including the readout and the information gatherers (such as a vial of some chemical).
</p>
<p>
The question is, does this tri-level hypothesis appear to make sense? It certainly seems as though it does. When we examine any machine that we have never seen before we must ask ourselves a few questions. First, we must ask ourselves what it looks like - we must examine it as a physical object. Secondly, we must attempt to determine how each physical part of this thing interacts with each other physical part - we must examine how it works. Thirdly, we must examine the output of the physical things operation to be able to determine what it does or what it gives from what it is given.
</p>
<p>
A typewriter, for example, looks a certain way - is physically a particular way (while at rest or while not being in operation). When we use the typewriter each piece interacts with each other piece in a particular way, which is determined by how the typewriter is made up (it&#39;s makeup prohibits the typewriter from acting in certain ways, but allows it to act in certain other ways). In addition, by inserting a piece of paper into the typewriter a certain way, and by using the typewriter in the way it was designed, we end with a piece of paper unlike the piece we inserted originally, in that the white sheet now contains black letters upon it (assuming of course that the paper was white in the first place and that we actually type some characters in - press some keys in/down).
</p>
<p>
Human cognition - information-processing by human beings - is not at all unlike our typewriter example. Human beings are designed (by nature or by the gods) to be a particular way physically. Specifically, our mind is set up in such and such a way, with particular properties and chemicals. In addition, our bodies, particularly our sense organs, are set up in a particular way. Together, united in a body, our senses work to gain information about the environment, including their (the senses&#39;) own place within the environment, by using some method or another, which our physical body has been set to carry out. Given this input, whatever it may be, we are then able to &#39;release&#39; some output.
</p>
<p>
We could next ask what role philosophy plays in cognitive science, particularly when in the context of the tri-level hypothesis. To be quite honest, while philosophers are said to be particularly of interest in the computational level, cognitive science, to me, is more about the scientific aspect than the cognitive aspect. Most of the issues of cognitive science, from Dawson&#39;s perspective, are about the actual system itself - most importantly the physical object that is engaging in information processing and the method that the information-processor follows, or acts out.
</p>
<p>
While we could pay special attention to human cognition, to information processors that are human, the tri-level hypothesis opens up the field much wider then this. Of course, it&#39;s possible that money is a main factor that would drive cognitive scientists towards studying human beings, with the hopes that an artificial intelligence could be created that would process information exactly as a human being. One would hope, however, that if we indeed do have philosophers in cognitive science, which Dawson holds is the case, that they would at least drive cognitive science not only towards the moneymaking projects, but towards the enlightening projects as well.
</p>
<p>
Which brings us again to the question of whether philosophy has a determined place in cognitive science, even though people in this field are possibly more interested in, and driven by, science and money. One possible answer, which I have some interest in, is that cognitive science takes quite a bit from philosophy, and therefore philosophy plays some role, but, instead of following completely through with philosophy, branches off into practical application. Philosophers have been interested in how it is that human beings interact with the world for quite a while - how it is that I know that there is a particular object before me. The primary purpose of this was to determine what the world outside of a perceiver is like, as well as how this perceiving worked. By knowing how perception - information processing - works, we can determine how it is that we come upon the truth. Cognitive science is merely the quest for this, not so as to know how human beings (how each &#39;I&#39;) perceives for that in itself, so as to be able to replicate this processing in an artificial construct.
</p>
<p>
The role of philosophy in cognitive science is like the role of a mentor, in that an older system helps guide the development of a newer system by both laying the groundwork, as well as giving aid when necessary. Philosophers, being more imaginative, abstract, and creative people, help move cognitive scientists towards the generation of a physical system. Because of this, while philosophy is the main driving force behind the basic/fundamental striving of the cognitive science field, philosophers-as-philosophers have little place in the further abstractions of this system. Rather, it is the philosophical psychologists and philosophical computer scientists that play a major part in these later abstractions.
</p>
<h3>Bibliography:</h3>
<p>
1. Michael Dawson, <em>Understanding Cognitive Science</em>, Blackwell Publishers, 1998.
</p>
<h3>Notes</h3>
<p>
<strong>Created:</strong> November 30th 2003<br />
<strong>Modified:</strong> December 8th 2003
</p>

