+++
title = "The Three Kinds of Inference"
description = "A brief discussion on the three types of inference; deduction, induction, and abduction, as well as a brief discussion of reduction as a kind of inference."
draft = false
comments = true
date = "2002-11-12T00:01:00-06:00"
modified = "2009-11-07T21:01:39-06:00"
slug = "The-Three-Kinds-of-Inference"
blogengine = "9bc3e7cd-7251-4cba-9e3a-6a29b756d182"
categories = ["article", "philosophy"]
tags = []
+++

<p>Recently, while listening to a philosophical discussion, I came to hear that there were not two kinds of inference (deductive and inductive), as I thought before, but instead that there were three kinds; deductive, inductive, and abductive. Wanting to know more about abductive reasoning, I did a little search, finding the following information.</p>
<!--more-->
<p>First, let's show deduction, by way of an example:</p>
<table style="width: 97%;" border="1" cellspacing="0" cellpadding="0">
<tbody>
<tr>
<td width="53%">1. All Dr. Pepper cans have white and red on their outside surface.</td>
<td width="46%">
<p>Premise</p>
</td>
</tr>
<tr>
<td width="53%">
<p>2. I have a Dr. Pepper can in my hand.</p>
</td>
<td width="46%">
<p>Premise</p>
</td>
</tr>
<tr>
<td width="53%">
<p>3. The can in my hand (the Dr. Pepper can) has white and red on its outside surface.</p>
</td>
<td width="46%">
<p>Conclusion by 1, 2 Constructive Dilemma (CD)</p>
</td>
</tr>
</tbody>
</table>
<p>Or, in other words, deductive arguments can be shown from their premises. We are first given a rule (the first premise), as well as a case (the second premise), and are then able to conclude with a result. So:</p>
<table style="width: 100%;" border="1" cellspacing="0" cellpadding="0">
<tbody>
<tr>
<td width="33%">Given:</td>
<td width="33%">
<p>and a:</p>
</td>
<td width="34%">
<p>we can get a:</p>
</td>
</tr>
<tr>
<td width="33%">
<p>Rule</p>
</td>
<td width="33%">
<p>Case</p>
</td>
<td width="34%">
<p>Result</p>
</td>
</tr>
</tbody>
</table>
<p>Deductive reasoning is, by far, the safest way to make a conclusion, as opposed to inductive and especially abductive reasoning. Notice that we could switch around number two (the second premise) and number three (the conclusion), removing the &ldquo;(the Dr. Pepper can)&rdquo;, and still have three true statements. However, the new number three in such a case would not follow from number 1 and the new number 2. Since I admit that my wording of this case is poor, let us see what I mean.</p>
<table style="width: 97%;" border="1" cellspacing="0" cellpadding="0">
<tbody>
<tr>
<td width="53%">
<p>1. All Dr. Pepper cans have white and red on their outside surface.</p>
</td>
<td width="46%">
<p>Premise</p>
</td>
</tr>
<tr>
<td width="53%">
<p>2. The can in my hand has white and red on its outside surface. (Was 3)</p>
</td>
<td width="46%">
<p>Premise</p>
</td>
</tr>
<tr>
<td width="53%">
<p>3. I have a Dr. Pepper can in my hand. (Was 2)</p>
</td>
<td width="46%">
<p>Conclusion</p>
</td>
</tr>
</tbody>
</table>
<p>Coca-Cola cans also have white and red on their surface, meaning that it&rsquo;s possible that I have a Coca-Cola can in my hand. Even though I haven&rsquo;t pointed this fact out (that Coca-Cola cans are white and red on their surface as well), that doesn&rsquo;t mean that we can&rsquo;t come up with an example that could be another possible conclusion. We&rsquo;ll see a bit more of this later, when we move into the other kinds of logical inference.</p>
<p>Another point to bring up about deduction is that it can be used as reductive reasoning. Reduction is taking a premise and simplifying it. Some would have us believe that this is not the same as deduction (see <em>Logic and Rhetoric</em>, by James William Johnson, for example), but I&rsquo;d like to hold that it is. Deduction doesn&rsquo;t necessarily have to be based upon two premises. Rather, it could be that one of the premises is fairly intensive, or full. For example,</p>
<table style="width: 97%;" border="1" cellspacing="0" cellpadding="0">
<tbody>
<tr>
<td width="53%">
<p>1. Murray the cat has white and yellow-brown fur, while Henry is all black, Tux is black and white, and Sophie is black, white, brown, and a bunch of other things.</p>
</td>
<td width="46%">
<p>Premise</p>
</td>
</tr>
</tbody>
</table>
<p>In most modern logic, we would have to break this single premise, which could be a sentence in real life, into four different premises, each dealing with a different cat. While these are typically restated as premises in modern logic (see #8, Simplification, in the above mentioned <a href="http://strivinglife.com/words/post/Rules-for-Sentential-Logic.aspx"><cite>Rules for Sentential Logic</cite></a>), it could be possible that we wish to end there, calling it a conclusion instead. For example, if I were to ask you, after telling you the above premise, what colour Sophie is, I wouldn&rsquo;t expect you to restate the entire premise. Instead, I would expect you to tell me &ldquo;Sophie is black, white, brown, and a bunch of other things&rdquo; &ndash; any other information, such as information about Murray, Henry, or Tux, would be unnecessary, and would only show that you can repeat information, not deduce information from statements.</p>
<p>The rules of deductive reasoning can be found in most logic books, and a list is contained in my paper mentioned above: <em>Rules for Sentential Logic</em>.</p>
<p>Inductive reasoning works with a case and a result, to determine a rule. For example,</p>
<table style="width: 100%;" border="1" cellspacing="0" cellpadding="0">
<tbody>
<tr>
<td width="50%">
<p>1. The sun has always risen every morning so far.</p>
</td>
<td width="50%">
<p>premise</p>
</td>
</tr>
<tr>
<td width="50%">
<p>2. The sun will rise tomorrow/every morning.</p>
</td>
<td width="50%">
<p>conclusion</p>
</td>
</tr>
</tbody>
</table>
<p>While the sun may not rise tomorrow (it may go supernova or the earth may break apart) we have a good reason to believe that it will rise.<!--adsense--></p>
<p>Deductive and inductive reasoning are also discussed by Monroe C. Beardsley, in <em>Practical Logic</em>. He states that deductive and inductive arguments each have two parts. The following is an idea of what he discusses in this book (page 201 of the 16th printing).</p>
<ul>
<li>Deductive argument argues that 
<ul>
<li>the reason is a set of one or more premises </li>
<li>the conclusion <em>necessarily</em> follows from the premises </li>
</ul>
</li>
<li>Inductive argument argues that 
<ul>
<li>the reason is a set of one or more statements called the evidence </li>
<li>the evidence sufficiently shows that the conclusion is more likely to be true then false </li>
</ul>
</li>
</ul>
<p>For the inductive argument, we saw that the evidence certainly points towards a scenario where the conclusion is true (namely that the sun will rise again, since it has every other time we have examined it). Of course, we can easily come up with a scenario where the evidence points to something that is not true, as I pointed out above. As Edmund Husserl states in his <em>Logical Investigations</em>, &ldquo;Induction does not establish the holding of the law, only the greater or lesser probability of its holding; the probability, and not the law, is justified by insight.&rdquo; [pg 47, Volume 1]</p>
<p>Abductive reasoning takes the final combination of; result, rule, case. So, we then get that abductive reasoning uses a result and a rule to get a case. Charles Peirce is attributed with the use of this reasoning. What this mainly states is that we observe some case/event A. If some rule R were true, then A would be an example of that rule in action (in other words, R would explain A). Therefore, we have seen that it is possible that R may be true, as we have observed A. I'll explain this by use of an example,</p>
<table style="width: 100%;" border="1" cellspacing="0" cellpadding="0">
<tbody>
<tr>
<td width="50%">1. My car is not where it is supposed to be.</td>
<td width="50%">
<p>premise</p>
</td>
</tr>
<tr>
<td width="50%">
<p>2. If someone has stolen my car, then it will not be where it is supposed to be.</p>
</td>
<td width="50%">
<p>premise</p>
</td>
</tr>
<tr>
<td width="50%">
<p>3. Someone has stolen my car.</p>
</td>
<td width="50%">
<p>conclusion</p>
</td>
</tr>
</tbody>
</table>
<p>Or, a better example, moving the 'given' and 'and a' around (so that it is "Given a Rule and a Result"):</p>
<table style="width: 100%;" border="1" cellspacing="0" cellpadding="0">
<tbody>
<tr>
<td width="50%">1. If someone has stolen my car, then it will not be where it is supposed to be.</td>
<td width="50%">
<p>premise</p>
</td>
</tr>
<tr>
<td width="50%">
<p>2. My car is not where it is supposed to be.</p>
</td>
<td width="50%">
<p>premise</p>
</td>
</tr>
<tr>
<td width="50%">
<p>3. Someone has stolen my car.</p>
</td>
<td width="50%">
<p>conclusion</p>
</td>
</tr>
</tbody>
</table>
<p>Of course, it's also possible that my car was towed, that somebody I know (and have given my keys to) has moved my car, or a flash flood has ripped through the area and moved my car ;) Abductive reasoning isn&rsquo;t as scientifically sound as inductive and deductive reasoning are, for this very reason &ndash; we can come to multiple conclusions based upon which rule we decide to apply, as long as the rule has some relevance to the case or event that we are attempting to explain.</p>
<p>To put the three together then, we have the following table:</p>
<table style="width: 100%;" border="1" cellspacing="0" cellpadding="0">
<tbody>
<tr>
<td width="24%"><span style="text-decoration: underline;">Inference Type:</span></td>
<td width="25%">
<p><span style="text-decoration: underline;">Given a:</span></p>
</td>
<td width="25%">
<p><span style="text-decoration: underline;">and a:</span></p>
</td>
<td width="25%">
<p><span style="text-decoration: underline;">we can get a:</span></p>
</td>
</tr>
<tr>
<td>
<p>Deduction</p>
</td>
<td>
<p>Rule</p>
</td>
<td>
<p>Case</p>
</td>
<td>
<p>Result</p>
</td>
</tr>
<tr>
<td>
<p>Induction</p>
</td>
<td>
<p>Case</p>
</td>
<td>
<p>Result</p>
</td>
<td>
<p>Rule</p>
</td>
</tr>
<tr>
<td>
<p>Abduction</p>
</td>
<td>
<p>Result</p>
</td>
<td>
<p>Rule</p>
</td>
<td>
<p>Case</p>
</td>
</tr>
</tbody>
</table>
<p>As I've seen put elsewhere, deductive reasoning applies previous knowledge to new cases. On the other hand, induction and abduction is used to acquire new knowledge.</p>
<p>Hopefully this makes sense, but I'm always open to suggestions and comments on my pieces if it does not.</p>
<h4>Notes</h4>
<p><strong>Created:</strong> November 20th 2002<br /><strong>Modified:</strong> February 6th 2003; October 24th 2003; February 9th 2004; August 6th 2004; August 16th 2004; September 23rd 2004; November 7th 2004</p>
<p>My previous knowledge in the field of logic was obtained in an undergraduate course, Elementary Logic. You can find some of the information that I learned in that class, in my paper titled <em>Rules for Sentential Logic</em>.</p>
